pub enum IrError {
GraphInvalid(Vec<GraphError>),
CycleDetected,
UnknownValue(ValueId),
UnknownNode(NodeId),
ShapeMismatch {
expected: Vec<usize>,
actual: Vec<usize>,
},
BroadcastIncompatible {
a: Vec<usize>,
b: Vec<usize>,
},
UnsupportedOpset {
domain: String,
version: u64,
},
}Expand description
Crate-level error for fallible IR operations.
Variants
GraphInvalid(Vec<GraphError>)
One or more structural defects were found by
Graph::validate.
CycleDetected
A cycle was detected while computing a topological order.
UnknownValue(ValueId)
A referenced value id is not live in the graph.
UnknownNode(NodeId)
A referenced node id is not live in the graph.
ShapeMismatch
Two shapes that were required to match did not.
BroadcastIncompatible
Two shapes could not be broadcast together.
UnsupportedOpset
An opset version the IR does not model.