WeightRef

Enum WeightRef 

pub enum WeightRef {
    Inline(TensorData),
    External {
        path: PathBuf,
        offset: usize,
        length: usize,
        dtype: DataType,
        dims: Vec<usize>,
    },
}
A reference to initializer (weight) data.

Small weights may be inlined; large weights are memory-mapped from an external file at load time (see docs/ORT2.md 12). The IR only stores the reference; the loader/onnx-runtime-memory crate performs the mmap.

Variants



Inline(TensorData)

Weight bytes stored inline in the model.



External

Weight bytes located in an external file at [offset, offset+length).

Fields

path: PathBuf
offset: usize
length: usize
dtype: DataType
dims: Vec<usize>

Implementations

Source

impl WeightRef

pub fn dtype(&self) -> DataType

The element type of the referenced weight.

pub fn dims(&self) -> &[usize]

The static dimensions of the referenced weight.